package App::Manoc::Controller::DHCPServer;
#ABSTRACT: DHCPServer Controller

use Moose;

our $VERSION = '2.99.3'; ##TRIAL VERSION

use namespace::autoclean;
BEGIN { extends 'App::Manoc::ControllerBase::CRUD' }

use App::Manoc::Form::DHCPServer;
use App::Manoc::Form::DHCPSharedNetwork;

__PACKAGE__->config(
    # define PathPart
    action => {
        setup => {
            PathPart => 'dhcpserver',
        }
    },
    class      => 'ManocDB::DHCPServer',
    form_class => 'App::Manoc::Form::DHCPServer',
);

__PACKAGE__->meta->make_immutable;

1;
# Local Variables:
# mode: cperl
# indent-tabs-mode: nil
# cperl-indent-level: 4
# cperl-indent-parens-as-block: t
# End:

__END__

=pod

=head1 NAME

App::Manoc::Controller::DHCPServer - DHCPServer Controller

=head1 VERSION

version 2.99.3

=head1 AUTHORS

=over 4

=item *

Gabriele Mambrini <gmambro@cpan.org>

=item *

Enrico Liguori

=back

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2017 by Gabriele Mambrini.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
